<div align="center">
    <br>
    <p align="center">
    <img src="https://i.imgur.com/kc7aE7z.png" 
         alt="scivision logo" width="60%" align="center">
    </p>
    <h2>A Toolkit for Scientific Image Analysis</h2>
</div>
 
<p align="center">
    <a href="https://pypi.org/project/scivision/">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/scivision">
    </a>
    <a href="https://mybinder.org/v2/gh/alan-turing-institute/scivision/HEAD?labpath=examples%2Fscivision-core-functionality.ipynb">
        <img alt="Binder" src="https://mybinder.org/badge_logo.svg">
    </a>
    <a href="https://github.com/scivision-gallery">
        <img alt="Scivision Gallery" src="https://img.shields.io/badge/Scivision-Gallery-pink">
    </a>
    <a href="https://github.com/alan-turing-institute/scivision/actions/workflows/scivision.yml">
        <img alt="Continuous integration badge" src="https://github.com/alan-turing-institute/scivision/actions/workflows/scivision.yml/badge.svg">
    </a>
    <a href="https://scivision.readthedocs.io/en/latest/?badge=latest">
        <img alt="Documentation Status" src="https://readthedocs.org/projects/scivision/badge/?version=latest">
    </a>
    <a href="https://github.com/alan-turing-institute/scivision/discussions">
       <img alt="Discuss on GitHub Discussions" src="https://img.shields.io/badge/GitHub-Discussions-yellow?logo=GitHub">
    </a>
    <a href="https://github.com/alan-turing-institute/scivision/blob/main/LICENSE">
        <img alt="License" src="https://img.shields.io/badge/License-BSD_3--Clause-blue.svg">
    </a>
    <br/>
</p>


The `scivision` project aims to connect **computer vision model developers** to **image data providers** from diverse scientific fields.

It's core features are:

1. The scivision **catalog**, containing pretrained computer vision models and datasets from science and the humanities
2. The scivision **model and datasource API**, a simple, standard interface to models and data that works with the entries in the catalog

The Scivision documentation is hosted on [Read the Docs](https://scivision.readthedocs.io/en/latest/) (including maintainer documentation). Start with the User Guide for an introduction to using Scivision.

You can also see an interactive demonstration of Scivision right now in your browser, no installation required: [![Launch Binder](https://img.shields.io/badge/Scivision-demo%20notebook-579ACA.svg?logo=data:image/png;base64, )](https://mybinder.org/v2/gh/alan-turing-institute/scivision/HEAD?labpath=examples%2Fscivision-core-functionality.ipynb)

Browse through a gallery of notebooks (runnable interactively with Binder) from research projects using Scivision at the [Scivision Gallery](https://github.com/scivision-gallery).

Scivision development happens in the [Scivision GitHub repo](https://github.com/alan-turing-institute/scivision).

## 🐨 Installation

1. **Install scivision via [PyPi](https://pypi.org/project/scivision/)**: which tends to be the most user-friendly option:

    ```bash
    pip install scivision
    ```

2. **Install scivision from the source code**:

    * Clone scivision source code:

    ```bash
    git clone https://github.com/alan-turing-institute/scivision.git 
    ```

    * Install scivision and its dependencies:

    ```bash
    cd /path/to/my/scivision
    pip install -v -e .
    ```

## 🤔 Contributing

See the [Contributing Guide on readthedocs](https://scivision.readthedocs.io/en/latest/contributing.html), which contains information on how to set up and contribute computer vision models and scientific image datasets to the scivision catalog, and make them available via the scivision python API, as well as modify the source code.

You may consider starting or joining in with a [discussion](https://github.com/alan-turing-institute/scivision/discussions), or opening an [issue](https://github.com/alan-turing-institute/scivision/issues) in this GitHub repo.
